%define build_external_fuse 1
# flag to allow local users to mount partitions. This is *really* not a good
# idea, because all users who have access to the device can do whatever they
# want with the data, and it also adds a root setuid binary to your system, so
# use it on your own risk. Refer to
# http://www.tuxera.com/community/ntfs-3g-faq/#useroption for details.
%define allow_unsafe_mount 0
%if %allow_unsafe_mount
# user mount only works if ntfs-3g is using internal fuse library
%define build_external_fuse 0
%endif

%bcond_without uclibc

Summary:	Read-write ntfs driver
Name:		ntfs-3g
Version:	2012.1.15
Release:	7
License:	GPLv2+
Group:		System/Base
Source0: 	http://tuxera.com/opensource/%{name}_ntfsprogs-%{version}.tgz
URL:		http://www.tuxera.com/community/ntfs-3g-download/
Obsoletes:      %mklibname ntfs-3g 0
Obsoletes:      %mklibname ntfs-3g 2
Obsoletes:      %mklibname ntfs-3g 10
Obsoletes:      %mklibname ntfs-3g 14
Obsoletes:      %mklibname ntfs-3g 16
Obsoletes:      %mklibname ntfs-3g 23
%rename ntfsprogs
BuildRequires:	attr-devel
%if %build_external_fuse
Buildrequires:  fuse-devel >= 2.8
Requires:	fuse >= 2.8
Requires(pre):	fuse >= 2.8
%else
Requires:	kmod(fuse)
%endif
%if %{with uclibc}
BuildRequires:	uClibc-devel >= 0.9.33.2-9
%endif
Conflicts:	ntfsprogs < 2.0.0-6

%description
The ntfs-3g package contains NTFS filesystem driver with read and 
write support. It provides safe and fast handling of MS Windows Vista, 
XP, 2000 and Server 2003 NTFS file systems. Most POSIX file system 
operations are supported.

%package -n	uclibc-%{name}
Summary:	Read-write ntfs driver (uClibc build)
Group:		System/Base

%description -n	uclibc-%{name}
The ntfs-3g package contains NTFS filesystem driver with read and 
write support. It provides safe and fast handling of MS Windows Vista, 
XP, 2000 and Server 2003 NTFS file systems. Most POSIX file system 
operations are supported.

%define	major	83
%define	libname	%mklibname %{name} %{major}
%package -n	%{libname}
Summary:	Library for reading & writing on NTFS filesystems
Group:		System/Base
Conflicts:	%{name} < 2012.1.15-2

%description -n	%{libname}
This is the library package for ntfs-3g.

%package -n	uclibc-%{libname}
Summary:	Library for reading & writing on NTFS filesystems (uClibc build)
Group:		System/Base

%description -n	uclibc-%{libname}
This is the library package for ntfs-3g.

%define	devname	%mklibname -d %{name}
%package -n	%{devname}
Summary:	Header files and static libraries for ntfs-3g
Group:		Development/C
Requires:	%{libname} = %{version}
%if %{with uclibc}
Requires:	uclibc-%{libname} = %{version}
%endif
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%mklibname -d %name
Obsoletes:	%mklibname -d %name 0
Obsoletes:	%mklibname -d %name 2
Obsoletes:	%mklibname -d %name 4
%rename		%{name}-devel
%rename		%{_lib}ntfs-devel

%description -n	%{devname}
You should install this package if you wish to develop applications that
use ntfs-3g.

%prep
%setup -qn %{name}_ntfsprogs-%{version}

%build
CONFIGURE_TOP=$PWD
%if %{with uclibc}
mkdir -p uclibc
pushd uclibc
%uclibc_configure \
	--disable-static \
	--prefix=%{_prefix} \
	--bindir=%{uclibc_root}/bin \
	--sbindir=%{uclibc_root}/sbin \
	--disable-ldconfig \
	--with-fuse=external

%make
popd
%endif

mkdir -p system
pushd system
%configure2_5x \
	CFLAGS="%{optflags} -fPIC" \
	--disable-static \
	--exec-prefix=/ \
	--bindir=/bin \
	--sbindir=/sbin \
	--disable-ldconfig \
%if %build_external_fuse
	--with-fuse=external
%else
	--with-fuse=internal
%endif
%make

%install
%if %{with uclibc}
%makeinstall_std -C uclibc
install -d %{buildroot}%{uclibc_root}/%{_lib}
for l in libntfs-3g.so; do
	rm %{buildroot}%{uclibc_root}%{_libdir}/${l}
	mv %{buildroot}%{uclibc_root}%{_libdir}/${l}.%{major}* %{buildroot}%{uclibc_root}/%{_lib}
	ln -sr %{buildroot}%{uclibc_root}/%{_lib}/${l}.%{major}.* %{buildroot}%{uclibc_root}%{_libdir}/${l}
done
mv %{buildroot}/sbin/* %{buildroot}%{uclibc_root}/sbin/
rm -r %{buildroot}%{uclibc_root}%{_libdir}/pkgconfig/
%endif
%makeinstall_std -C system
install -d %{buildroot}/%{_lib}
for l in libntfs-3g.so; do
	rm %{buildroot}%{_libdir}/${l}
	mv %{buildroot}%{_libdir}/${l}.%{major}* %{buildroot}/%{_lib}
	ln -sr %{buildroot}/%{_lib}/${l}.%{major}.* %{buildroot}%{_libdir}/${l}
done

ln -sf /sbin/mount.ntfs-3g %{buildroot}/sbin/mount.ntfs
ln -sf /sbin/mount.ntfs-3g %{buildroot}/sbin/mount.ntfs-fuse
mkdir -p %{buildroot}%{_bindir}
ln -sf /sbin/mount.ntfs-3g %{buildroot}%{_bindir}/ntfsmount

# remove doc files, as we'll cp them later
rm -r %{buildroot}%{_datadir}/doc

%files
%doc README AUTHORS CREDITS NEWS
%{_bindir}/ntfsmount
/bin/lowntfs-3g
/bin/ntfs-3g
/bin/ntfs-3g.probe
/bin/ntfs-3g.secaudit
/bin/ntfs-3g.usermap
/bin/ntfscat
/bin/ntfscluster
/bin/ntfscmp
/bin/ntfsfix
/bin/ntfsinfo
/bin/ntfsls
/sbin/mkfs.ntfs
/sbin/mkntfs
/sbin/ntfsclone
/sbin/ntfscp
/sbin/ntfslabel
/sbin/ntfsresize
/sbin/ntfsundelete
%{_mandir}/man8/*
%if %allow_unsafe_mount
%attr(4755,root,root) /sbin/mount.ntfs-3g
%else
%attr(754,root,root) /sbin/mount.ntfs-3g
%endif
/sbin/mount.ntfs
/sbin/mount.lowntfs-3g
/sbin/mount.ntfs-fuse

%files -n uclibc-%{name}
#%{uclibc_root}%{_bindir}/ntfsmount
%{uclibc_root}/bin/lowntfs-3g
%{uclibc_root}/bin/ntfs-3g
%{uclibc_root}/bin/ntfs-3g.probe
%{uclibc_root}/bin/ntfs-3g.secaudit
%{uclibc_root}/bin/ntfs-3g.usermap
%{uclibc_root}/bin/ntfscat
%{uclibc_root}/bin/ntfscluster
%{uclibc_root}/bin/ntfscmp
%{uclibc_root}/bin/ntfsfix
%{uclibc_root}/bin/ntfsinfo
%{uclibc_root}/bin/ntfsls
%{uclibc_root}/sbin/mkfs.ntfs
%{uclibc_root}/sbin/mkntfs
%{uclibc_root}/sbin/ntfsclone
%{uclibc_root}/sbin/ntfscp
%{uclibc_root}/sbin/ntfslabel
%{uclibc_root}/sbin/ntfsresize
%{uclibc_root}/sbin/ntfsundelete
%if %allow_unsafe_mount
%attr(4755,root,root) %{uclibc_root}/sbin/mount.ntfs-3g
%else
%attr(754,root,root) %{uclibc_root}/sbin/mount.ntfs-3g
%endif
#%{uclibc_root}/sbin/mount.ntfs
%{uclibc_root}/sbin/mount.lowntfs-3g
#%{uclibc_root}/sbin/mount.ntfs-fuse

%files -n %{libname}
/%{_lib}/libntfs-3g.so.*

%files -n uclibc-%{libname}
%{uclibc_root}/%{_lib}/libntfs-3g.so.*

%files -n %{devname}
%doc ChangeLog
%{_libdir}/libntfs-3g.so
%if %{with uclibc}
%{uclibc_root}%{_libdir}/libntfs-3g.so
%endif
%{_includedir}/ntfs-3g
%{_libdir}/pkgconfig/*.pc


%changelog
* Sat Nov 03 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 2012.1.15-7
+ Revision: 821715
- let's see if thiings has been cleared enough properly to make out way this time

* Fri Nov 02 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 2012.1.15-6
+ Revision: 821676
- reupload again now that old libntfs-devel package  really should be gone...

* Thu Nov 01 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 2012.1.15-4
+ Revision: 821563
- obsolete old libntfs-devel package

* Tue Oct 30 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 2012.1.15-3
+ Revision: 821191
- drop bogus lib%%{name}-devel provides
- build against external fuse for uclibc build as well
- use %%uclibc_configure macro

* Fri Sep 28 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 2012.1.15-2
+ Revision: 817854
- keep symlinks for uclibc build
- keep /sbin/mount.ntfs-3g as a symlink
- use internal fuse for uclibc build
- cleanups
- make hardlink rather than copy...
- do uclibc build
- libify package

* Mon Jan 23 2012 Alexander Khrukin <akhrukin@mandriva.org> 2012.1.15-1
+ Revision: 767387
- .a files removed in cooker
- version update 2012.15 hal policy removed

* Mon Apr 11 2011 Funda Wang <fwang@mandriva.org> 2011.4.12-2
+ Revision: 652560
- merge ntfsprogs and ntfs-3g

* Mon Apr 11 2011 Funda Wang <fwang@mandriva.org> 2011.4.12-1
+ Revision: 652559
- new version 2011.4.12

* Mon Jan 24 2011 Funda Wang <fwang@mandriva.org> 2011.1.15-1
+ Revision: 632472
- update to new version 2011.1.15

* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 2010.10.2-2mdv2011.0
+ Revision: 606830
- rebuild

* Mon Oct 04 2010 Funda Wang <fwang@mandriva.org> 2010.10.2-1mdv2011.0
+ Revision: 582800
- New version 2010.10.2

* Mon Aug 09 2010 Funda Wang <fwang@mandriva.org> 2010.8.8-1mdv2011.0
+ Revision: 567843
- update to new version 2010.8.8
- add conflicts on older ntfsprogs

* Sun Jul 11 2010 Funda Wang <fwang@mandriva.org> 2010.5.22-1mdv2011.0
+ Revision: 550636
- New version 2010.5.22

* Mon May 17 2010 Eugeni Dodonov <eugeni@mandriva.com> 2010.5.16-1mdv2011.0
+ Revision: 544955
- Updated to 2010.5.16.

* Tue Mar 30 2010 Eugeni Dodonov <eugeni@mandriva.com> 2010.3.6-3mdv2010.1
+ Revision: 529725
- Add a flag to allow enabling user mounts (#45476).

* Mon Mar 15 2010 Eugeni Dodonov <eugeni@mandriva.com> 2010.3.6-2mdv2010.1
+ Revision: 519941
- Provide mount.ntfs, mount.ntfs-fuse and ntfsmount.

* Tue Mar 09 2010 Funda Wang <fwang@mandriva.org> 2010.3.6-1mdv2010.1
+ Revision: 516823
- New version 2010.3.6
- update desc

* Mon Jan 18 2010 Funda Wang <fwang@mandriva.org> 2010.1.16-2mdv2010.1
+ Revision: 493078
- use root group rather than fuse (bug#57113)

* Mon Jan 18 2010 Funda Wang <fwang@mandriva.org> 2010.1.16-1mdv2010.1
+ Revision: 492931
- New version 2010.1.16
- update url

* Mon Nov 16 2009 Funda Wang <fwang@mandriva.org> 2009.11.14-1mdv2010.1
+ Revision: 466631
- fix build
- new version 2009.11.14

* Mon Sep 21 2009 Eugeni Dodonov <eugeni@mandriva.com> 2009.4.4-2mdv2010.0
+ Revision: 446533
- Installing ntfs-3g as default driver for ntfs partitions (#53795).

* Fri Apr 03 2009 Frederic Crozat <fcrozat@mandriva.com> 2009.4.4-1mdv2009.1
+ Revision: 363764
- Release 2009.4.4
- Remove patch1 (fixed upstream)

* Tue Mar 31 2009 Funda Wang <fwang@mandriva.org> 2009.3.8-1mdv2009.1
+ Revision: 362967
- New version 2009.3.8

* Mon Mar 30 2009 Pascal Terjan <pterjan@mandriva.org> 2009.2.1-3mdv2009.1
+ Revision: 362378
- Update /etc/mtab but do not wait for the process

* Fri Mar 27 2009 Pascal Terjan <pterjan@mandriva.org> 2009.2.1-2mdv2009.1
+ Revision: 361736
- Disable mtab updating until a solution for deadlock is found

* Thu Feb 12 2009 Frederik Himpe <fhimpe@mandriva.org> 2009.2.1-1mdv2009.1
+ Revision: 339900
- update to new version 2009.2.1

* Fri Jan 23 2009 Funda Wang <fwang@mandriva.org> 2009.1.1-1mdv2009.1
+ Revision: 332743
- new version 2009.1.1

* Tue Dec 02 2008 Funda Wang <fwang@mandriva.org> 1.5130-1mdv2009.1
+ Revision: 309199
- update to new version 1.5130

* Sun Oct 12 2008 Funda Wang <fwang@mandriva.org> 1.5012-1mdv2009.1
+ Revision: 292619
- New version 1.5012

* Fri Sep 19 2008 Funda Wang <fwang@mandriva.org> 1.2918-1mdv2009.0
+ Revision: 285808
- New version 1.2918

* Sat Aug 16 2008 Funda Wang <fwang@mandriva.org> 1.2812-2mdv2009.0
+ Revision: 272609
- New version 1.2812

* Tue Jul 29 2008 Funda Wang <fwang@mandriva.org> 1.2712-2mdv2009.0
+ Revision: 252183
- fix perms (bug#42306)
- remove incorrect doc dir

* Tue Jul 15 2008 Funda Wang <fwang@mandriva.org> 1.2712-1mdv2009.0
+ Revision: 235723
- New version 1.2712
- use internal fuse even in cooker, as external dependency requires fuse 2.8

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Thu May 29 2008 Funda Wang <fwang@mandriva.org> 1.2531-1mdv2009.0
+ Revision: 213061
- New version 1.2531

* Wed May 07 2008 Funda Wang <fwang@mandriva.org> 1.2506-1mdv2009.0
+ Revision: 202735
- New version 1.2506

* Tue Apr 15 2008 Funda Wang <fwang@mandriva.org> 1.2412-1mdv2009.0
+ Revision: 193607
- New version 1.2412
- obsoletes libntfs-3g, as it produces too many libmajor, and it is not used by other packages
- New version 1.2310
- add fedora patch to fix rhbug#403291 (ignore -n option)

* Mon Feb 18 2008 Funda Wang <fwang@mandriva.org> 1.2216-1mdv2008.1
+ Revision: 171456
- New version 1.2216

* Fri Feb 08 2008 Funda Wang <fwang@mandriva.org> 1.2129-4mdv2008.1
+ Revision: 164013
- move prefix from /usr to /, which solve the problems if
  /usr is not mounted at boot time.

* Fri Feb 01 2008 Funda Wang <fwang@mandriva.org> 1.2129-3mdv2008.1
+ Revision: 161148
- mount.ntfs-3g should be in /sbin rather thatn /usr/sbin (bug#37352)

* Tue Jan 29 2008 Funda Wang <fwang@mandriva.org> 1.2129-2mdv2008.1
+ Revision: 159884
- fuse is not required for old distro
- add conditional building for fuse

* Tue Jan 29 2008 Funda Wang <fwang@mandriva.org> 1.2129-1mdv2008.1
+ Revision: 159810
- New version 1.2129

  + Olivier Blin <blino@mandriva.org>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Nov 20 2007 Funda Wang <fwang@mandriva.org> 1.1120-1mdv2008.1
+ Revision: 110711
- New version 1.1104
- New major ( 14-> 16 )

* Tue Nov 06 2007 Funda Wang <fwang@mandriva.org> 1.1104-2mdv2008.1
+ Revision: 106394
- rebuild for new lzma

* Mon Nov 05 2007 Funda Wang <fwang@mandriva.org> 1.1104-1mdv2008.1
+ Revision: 106003
- New version 1.1104

* Thu Nov 01 2007 Funda Wang <fwang@mandriva.org> 1.1030-1mdv2008.1
+ Revision: 104318
- New version 1.1030
- New major ( 13 -> 14 )

* Sun Oct 14 2007 Funda Wang <fwang@mandriva.org> 1.1004-2mdv2008.1
+ Revision: 98262
- drop README.install.urpmi, as our kernel is new enough

* Tue Oct 09 2007 Funda Wang <fwang@mandriva.org> 1.1004-1mdv2008.1
+ Revision: 96173
- New major
- New version 1.1004

* Thu Aug 30 2007 Funda Wang <fwang@mandriva.org> 1.826-1mdv2008.0
+ Revision: 75140
- New major
- New version 1.826

* Sun Aug 12 2007 Funda Wang <fwang@mandriva.org> 1.810-1mdv2008.0
+ Revision: 62256
- new major
- New version 1.810

* Thu Jul 26 2007 Helio Chissini de Castro <helio@mandriva.com> 1.710-2mdv2008.0
+ Revision: 56065
- Elegant solution from ArchLinux to enable hal backends to use ntfs-3g instead of standard ntfs
  driver. KDE now mount external and local ntfs storage devices rw by default as long ntfs-3f is
  installed. gnome-mount is not affected, as use different strategy.

  + Götz Waschk <waschk@mandriva.org>
    - fix doc file listing

* Mon Jul 16 2007 Götz Waschk <waschk@mandriva.org> 1.710-1mdv2008.0
+ Revision: 52424
- new version
- rename devel package

* Sun Jun 24 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.616-1mdv2008.0
+ Revision: 43669
- new version: 1.616
- new major

* Fri May 25 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.516-1mdv2008.0
+ Revision: 31052
- build on all architectures (worked just fine on my sparc :)
- new release: 1.516
  new major
  add url to source


* Thu Feb 22 2007 Götz Waschk <waschk@mandriva.org> 1.0-2mdv2007.0
+ Revision: 124370
- fix description
- fix group
- add warning about FUSE version

  + Frederic Crozat <fcrozat@mandriva.com>
    - Fix description

* Wed Feb 21 2007 Götz Waschk <waschk@mandriva.org> 1.0-1mdv2007.1
+ Revision: 123213
- new version
- fix build
- remove warning at installation, this isn't considered beta anymore

  + Thierry Vignaud <tvignaud@mandriva.com>
    - new URL

  + Jérôme Soyer <saispo@mandriva.org>
    - Import ntfs-3g

* Tue Sep 26 2006 Couriousous <couriousous@mandriva.org> 0.1-0.20070920.1mdv2007.0
- 20070920-BETA

* Fri Jul 21 2006 Couriousous <couriousous@mandriva.org> 0.1-0.20070714.2mdv2007.0
- Some spec cleanup
- Build only on ix86
- Upload to contrib

* Thu Jul 20 2006 Davide Duina <davide.duina_AT_gmail_DOT_com> 0.1-0.20070714.1mdv2007.0
- First version, based on Beta 20070714

